==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QLogicalDevice.java <==
package io.qt.qt3d.input;


/**
 * <p>Allows the user to define a set of actions that they wish to use within an application</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html">Qt3DInput::QLogicalDevice</a></p>
 */
public class QLogicalDevice extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogicalDevice.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLogicalDevice(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogicalDevice() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#QLogicalDevice">Qt3DInput::QLogicalDevice::QLogicalDevice(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLogicalDevice(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogicalDevice instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#actions">Qt3DInput::QLogicalDevice::actions()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.input.QAction> actions(){
        return actions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.input.QAction> actions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#addAction">Qt3DInput::QLogicalDevice::addAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addAction(io.qt.qt3d.input.QAction action){
        addAction_native_Qt3DInput_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
    }
    
    @io.qt.QtUninvokable
    private native void addAction_native_Qt3DInput_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#addAxis">Qt3DInput::QLogicalDevice::addAxis(Qt3DInput::QAxis*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addAxis(io.qt.qt3d.input.QAxis axis){
        addAxis_native_Qt3DInput_QAxis_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(axis));
    }
    
    @io.qt.QtUninvokable
    private native void addAxis_native_Qt3DInput_QAxis_ptr(long __this__nativeId, long axis);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#axes">Qt3DInput::QLogicalDevice::axes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.input.QAxis> axes(){
        return axes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.input.QAxis> axes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#removeAction">Qt3DInput::QLogicalDevice::removeAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeAction(io.qt.qt3d.input.QAction action){
        removeAction_native_Qt3DInput_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
    }
    
    @io.qt.QtUninvokable
    private native void removeAction_native_Qt3DInput_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qlogicaldevice.html#removeAxis">Qt3DInput::QLogicalDevice::removeAxis(Qt3DInput::QAxis*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeAxis(io.qt.qt3d.input.QAxis axis){
        removeAxis_native_Qt3DInput_QAxis_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(axis));
    }
    
    @io.qt.QtUninvokable
    private native void removeAxis_native_Qt3DInput_QAxis_ptr(long __this__nativeId, long axis);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLogicalDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLogicalDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLogicalDevice instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.2.2-sources.jar: io/qt/qt3d/input/QLogicalDevice.java <==
package io.qt.qt3d.input;


/**
 * <p>Allows the user to define a set of actions that they wish to use within an application</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html">Qt3DInput::QLogicalDevice</a></p>
 */
public class QLogicalDevice extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogicalDevice.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLogicalDevice(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogicalDevice() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#QLogicalDevice">Qt3DInput::QLogicalDevice::QLogicalDevice(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLogicalDevice(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogicalDevice instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#actions">Qt3DInput::QLogicalDevice::actions()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.input.QAction> actions(){
        return actions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.input.QAction> actions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#addAction">Qt3DInput::QLogicalDevice::addAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addAction(io.qt.qt3d.input.QAction action){
        addAction_native_Qt3DInput_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
    }
    
    @io.qt.QtUninvokable
    private native void addAction_native_Qt3DInput_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#addAxis">Qt3DInput::QLogicalDevice::addAxis(Qt3DInput::QAxis*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addAxis(io.qt.qt3d.input.QAxis axis){
        addAxis_native_Qt3DInput_QAxis_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(axis));
    }
    
    @io.qt.QtUninvokable
    private native void addAxis_native_Qt3DInput_QAxis_ptr(long __this__nativeId, long axis);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#axes">Qt3DInput::QLogicalDevice::axes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.input.QAxis> axes(){
        return axes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.input.QAxis> axes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#removeAction">Qt3DInput::QLogicalDevice::removeAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeAction(io.qt.qt3d.input.QAction action){
        removeAction_native_Qt3DInput_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
    }
    
    @io.qt.QtUninvokable
    private native void removeAction_native_Qt3DInput_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qlogicaldevice.html#removeAxis">Qt3DInput::QLogicalDevice::removeAxis(Qt3DInput::QAxis*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeAxis(io.qt.qt3d.input.QAxis axis){
        removeAxis_native_Qt3DInput_QAxis_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(axis));
    }
    
    @io.qt.QtUninvokable
    private native void removeAxis_native_Qt3DInput_QAxis_ptr(long __this__nativeId, long axis);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLogicalDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLogicalDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLogicalDevice instance, QDeclarativeConstructor constructor);
    
}
